## TODO: Separate by time aggregation

get_filename <- function(dir, var, date, fcst.sdate, agg, horizon, file.type) {
  # This function builds the path of the output file based on directory,
  # variable, forecast date, startdate, aggregation, forecast horizon and
  # type of metric/forecast/probability.
    
  if (horizon == "subseasonal") {
    shortdate <- format(as.Date(as.character(fcst.sdate), "%Y%m%d"), "%V")
    dd <- "week"
  } else {
    shortdate <- format(as.Date(as.character(fcst.sdate), "%Y%m%d"), "%m")
    dd <- "month"
  }
  
  switch(tolower(agg),
	 "country" = {gg <- "-country"},
         "global" = {gg <- ""})

  switch(file.type,
	 "skill" = {file <- paste0(var, gg, "-skill_", dd, shortdate)},
	 "corr" = {file <- paste0(var, gg, "-corr_", dd, shortdate)},
	 "exp" = {file <- paste0(var, gg, "_", date)},
	 "obs" = {file <- paste0(var, gg, "-obs_", date)},
	 "percentiles" = {file <- paste0(var, gg, "-percentiles_", dd, 
					 shortdate)},
	 "probs" = {file <- paste0(var, gg, "-probs_", date)},
	 "bias" = {file <- paste0(var, gg, "-bias_", date)})

  return(paste0(dir, file, ".nc"))

}

get_dir <- function(recipe, agg = "global") {
  # This function builds the path for the output directory. The output
  # directories will be subdirectories within outdir, organized by variable,
  # startdate, and aggregation.

  ## TODO: Get aggregation from recipe
  ## TODO: Add time frequency

  outdir <- paste0(recipe$Run$output_dir, "/outputs/")
  variable <- recipe$Analysis$Variables$name
  if (!is.null(recipe$Analysis$Time$fcst_year)) {
    if (tolower(recipe$Analysis$Horizon) == 'decadal') {
      #PROBLEM: decadal doesn't have sdate
      fcst.sdate <- paste0(recipe$Analysis$Time$fcst_year, collapse = '_')
    } else {
      fcst.sdate <- paste0(recipe$Analysis$Time$fcst_year,
  	                   recipe$Analysis$Time$sdate)
    }
  } else {
    if (tolower(recipe$Analysis$Horizon) == 'decadal') {
      #PROBLEM: decadal doesn't have sdate
      fcst.sdate <- paste0("hcst-", paste(recipe$Analysis$Time$hcst_start, recipe$Analysis$Time$hcst_end, sep = '_'))
    } else {
      fcst.sdate <- paste0("hcst-", recipe$Analysis$Time$sdate)
    }
  }

  calib.method <- tolower(recipe$Analysis$Workflow$Calibration$method)
  store.freq <- recipe$Analysis$Variables$freq
  
  switch(tolower(agg),
	 "country" = {dir <- paste0(outdir, "/", calib.method, "-",
				    store.freq, "/", variable, 
	             		    "_country/", fcst.sdate, "/")},
	 "global" = {dir <- paste0(outdir, "/", calib.method, "-", 
				   store.freq, "/", variable, "/",
				   fcst.sdate, "/")})

  return(dir)

}
